@@ -25,7 +25,8 @@ public:
         YouTube,
         Install,
         Ovi,
-        iCal
+        iCal,
+        Apt
     };
     // inherited virtuals
     QrSink(const PluginInterface *interface);
@@ -48,6 +49,7 @@ private:
     void openBrowser(QString uri);
     void addMECARD(QString user_data);
     void openGeo(QString data);
+    void openApt(QString data);
 
     QString buttonText;
     QString barcodeText;
